@@ -46,8 +46,10 @@ import qutebrowser.resources
 from qutebrowser.completion.models import instances as completionmodels
 from qutebrowser.commands import cmdutils, runners, cmdexc
 from qutebrowser.config import style, config, websettings, configexc
-from qutebrowser.browser import urlmarks, cookies, cache, adblock, history
-from qutebrowser.browser.network import qutescheme, proxy, networkmanager
+from qutebrowser.browser import urlmarks, adblock
+from qutebrowser.browser.webkit import cookies, cache, history, downloads
+from qutebrowser.browser.webkit.network import (qutescheme, proxy,
+                                                networkmanager)
 from qutebrowser.mainwindow import mainwindow
 from qutebrowser.misc import readline, ipc, savemanager, sessions, crashsignal
 from qutebrowser.misc import utilcmds  # pylint: disable=unused-import
@@ -62,12 +64,7 @@ qApp = None
 def run(args):
     """Initialize everything and run the application."""
     if args.version:
-        print(version.version(short=True))
-        print()
-        print()
-        print(qutebrowser.__copyright__)
-        print()
-        print(version.GPL_BOILERPLATE.strip())
+        print(version.version())
         sys.exit(usertypes.Exit.ok)
 
     if args.temp_basedir:
@@ -166,7 +163,7 @@ def _init_icon():
     """Initialize the icon of qutebrowser."""
     icon = QIcon()
     fallback_icon = QIcon()
-    for size in (16, 24, 32, 48, 64, 96, 128, 256, 512):
+    for size in [16, 24, 32, 48, 64, 96, 128, 256, 512]:
         filename = ':/icons/qutebrowser-{}x{}.png'.format(size, size)
         pixmap = QPixmap(filename)
         qtutils.ensure_not_null(pixmap)
@@ -278,7 +275,7 @@ def process_pos_args(args, via_ipc=False, cwd=None, target_arg=None):
                 message.error('current', "Error in startup argument '{}': "
                               "{}".format(cmd, e))
             else:
-                background = open_target in ('tab-bg', 'tab-bg-silent')
+                background = open_target in ['tab-bg', 'tab-bg-silent']
                 tabbed_browser.tabopen(url, background=background,
                                        explicit=True)
 
@@ -340,7 +337,6 @@ def _save_version():
     state_config['general']['version'] = qutebrowser.__version__
 
 
-@pyqtSlot('QWidget*', 'QWidget*')
 def on_focus_changed(_old, new):
     """Register currently focused main window in the object registry."""
     if not isinstance(new, QWidget):
@@ -358,9 +354,8 @@ def on_focus_changed(_old, new):
         _maybe_hide_mouse_cursor()
 
 
-@pyqtSlot(QUrl)
 def open_desktopservices_url(url):
-    """Handler to open an URL via QDesktopServices."""
+    """Handler to open a URL via QDesktopServices."""
     win_id = mainwindow.get_window(via_ipc=True, force_window=False)
     tabbed_browser = objreg.get('tabbed-browser', scope='window',
                                 window=win_id)
@@ -441,6 +436,8 @@ def _init_modules(args, crash_handler):
         os.environ.pop('QT_WAYLAND_DISABLE_WINDOWDECORATION', None)
     _maybe_hide_mouse_cursor()
     objreg.get('config').changed.connect(_maybe_hide_mouse_cursor)
+    temp_downloads = downloads.TempDownloadManager(qApp)
+    objreg.register('temporary-downloads', temp_downloads)
 
 
 def _init_late_modules(args):
@@ -479,7 +476,6 @@ class Quitter:
         self._shutting_down = False
         self._args = args
 
-    @pyqtSlot()
     def on_last_window_closed(self):
         """Slot which gets invoked when the last window was closed."""
         self.shutdown(last_window=True)
@@ -494,7 +490,7 @@ class Quitter:
         else:
             path = os.path.abspath(os.path.dirname(qutebrowser.__file__))
             if not os.path.isdir(path):
-                # Probably running from an python egg.
+                # Probably running from a python egg.
                 return
 
         for dirpath, _dirnames, filenames in os.walk(path):
@@ -527,7 +523,7 @@ class Quitter:
             cwd = os.path.join(os.path.abspath(os.path.dirname(
                                qutebrowser.__file__)), '..')
             if not os.path.isdir(cwd):
-                # Probably running from an python egg. Let's fallback to
+                # Probably running from a python egg. Let's fallback to
                 # cwd=None and see if that works out.
                 # See https://github.com/The-Compiler/qutebrowser/issues/323
                 cwd = None
@@ -714,6 +710,8 @@ class Quitter:
                 not restart):
             atexit.register(shutil.rmtree, self._args.basedir,
                             ignore_errors=True)
+        # Delete temp download dir
+        objreg.get('temporary-downloads').cleanup()
         # If we don't kill our custom handler here we might get segfaults
         log.destroy.debug("Deactivating message handler...")
         qInstallMessageHandler(None)
