@@ -23,7 +23,7 @@ import os
 
 from PyQt5.QtCore import QUrl
 
-from qutebrowser.browser import webelem
+from qutebrowser.browser.webkit import webelem
 from qutebrowser.utils import utils
 
 
@@ -69,7 +69,7 @@ def _generate_pdfjs_script(url):
 
 
 def fix_urls(asset):
-    """Take a html page and replace each relative URL with an absolute.
+    """Take an html page and replace each relative URL with an absolute.
 
     This is specialized for pdf.js files and not a general purpose function.
 
