@@ -52,7 +52,8 @@ SELECTORS = {
     Group.focus: '*:focus',
     Group.inputs: ('input[type=text], input[type=email], input[type=url], '
                    'input[type=tel], input[type=number], '
-                   'input[type=password], input[type=search], textarea'),
+                   'input[type=password], input[type=search], '
+                   'input:not([type]), textarea'),
 }
 
 
