@@ -22,14 +22,13 @@
 import collections
 import functools
 
-from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QSize, QRect, QTimer
+from PyQt5.QtCore import pyqtSignal, pyqtSlot, Qt, QSize, QRect, QTimer, QUrl
 from PyQt5.QtWidgets import (QTabWidget, QTabBar, QSizePolicy, QCommonStyle,
                              QStyle, QStylePainter, QStyleOptionTab)
 from PyQt5.QtGui import QIcon, QPalette, QColor
 
 from qutebrowser.utils import qtutils, objreg, utils, usertypes
 from qutebrowser.config import config
-from qutebrowser.browser import webview
 
 
 PixelMetrics = usertypes.enum('PixelMetrics', ['icon_padding'],
@@ -73,7 +72,7 @@ class TabWidget(QTabWidget):
         position = config.get('tabs', 'position')
         selection_behavior = config.get('tabs', 'select-on-remove')
         self.setTabPosition(position)
-        tabbar.vertical = position in (QTabWidget.West, QTabWidget.East)
+        tabbar.vertical = position in [QTabWidget.West, QTabWidget.East]
         tabbar.setSelectionBehaviorOnRemove(selection_behavior)
         tabbar.refresh()
 
@@ -99,21 +98,38 @@ class TabWidget(QTabWidget):
 
     def update_tab_title(self, idx):
         """Update the tab text for the given tab."""
-        widget = self.widget(idx)
-        page_title = self.page_title(idx).replace('&', '&&')
+        fields = self.get_tab_fields(idx)
+        fields['title'] = fields['title'].replace('&', '&&')
+        fields['index'] = idx + 1
+
+        fmt = config.get('tabs', 'title-format')
+        self.tabBar().setTabText(idx, fmt.format(**fields))
+
+    def get_tab_fields(self, idx):
+        """Get the tab field data."""
+        tab = self.widget(idx)
+        page_title = self.page_title(idx)
 
         fields = {}
-        if widget.load_status == webview.LoadStatus.loading:
-            fields['perc'] = '[{}%] '.format(widget.progress)
+        fields['id'] = tab.tab_id
+        fields['title'] = page_title
+        fields['title_sep'] = ' - ' if page_title else ''
+        fields['perc_raw'] = tab.progress()
+
+        if tab.load_status() == usertypes.LoadStatus.loading:
+            fields['perc'] = '[{}%] '.format(tab.progress())
         else:
             fields['perc'] = ''
-        fields['perc_raw'] = widget.progress
-        fields['title'] = page_title
-        fields['index'] = idx + 1
-        fields['id'] = widget.tab_id
-        fields['title_sep'] = ' - ' if page_title else ''
-        y = widget.scroll_pos[1]
-        if y <= 0:
+
+        try:
+            fields['host'] = self.tab_url(idx).host()
+        except qtutils.QtValueError:
+            fields['host'] = ''
+
+        y = tab.scroller.pos_perc()[1]
+        if y is None:
+            scroll_pos = '???'
+        elif y <= 0:
             scroll_pos = 'top'
         elif y >= 100:
             scroll_pos = 'bot'
@@ -121,9 +137,7 @@ class TabWidget(QTabWidget):
             scroll_pos = '{:2}%'.format(y)
 
         fields['scroll_pos'] = scroll_pos
-
-        fmt = config.get('tabs', 'title-format')
-        self.tabBar().setTabText(idx, fmt.format(**fields))
+        return fields
 
     @config.change_filter('tabs', 'title-format')
     def update_tab_titles(self):
@@ -205,6 +219,21 @@ class TabWidget(QTabWidget):
         self.tabBar().on_change()
         self.tab_index_changed.emit(index, self.count())
 
+    def tab_url(self, idx):
+        """Get the URL of the tab at the given index.
+
+        Return:
+            The tab URL as QUrl.
+        """
+        tab = self.widget(idx)
+        if tab is None:
+            url = QUrl()
+        else:
+            url = tab.url()
+        # It's possible for url to be invalid, but the caller will handle that.
+        qtutils.ensure_valid(url)
+        return url
+
 
 class TabBar(QTabBar):
 
@@ -513,11 +542,11 @@ class TabBarStyle(QCommonStyle):
             style: The base/"parent" style.
         """
         self._style = style
-        for method in ('drawComplexControl', 'drawItemPixmap',
+        for method in ['drawComplexControl', 'drawItemPixmap',
                        'generatedIconPixmap', 'hitTestComplexControl',
                        'itemPixmapRect', 'itemTextRect', 'polish', 'styleHint',
                        'subControlRect', 'unpolish', 'drawItemText',
-                       'sizeFromContents', 'drawPrimitive'):
+                       'sizeFromContents', 'drawPrimitive']:
             target = getattr(self._style, method)
             setattr(self, method, functools.partial(target))
         super().__init__()
