@@ -36,8 +36,8 @@ from PyQt5.QtWidgets import (QDialog, QLabel, QTextEdit, QPushButton,
 
 import qutebrowser
 from qutebrowser.utils import version, log, utils, objreg
-from qutebrowser.misc import miscwidgets, autoupdate, msgbox, httpclient
-from qutebrowser.browser.network import pastebin
+from qutebrowser.misc import (miscwidgets, autoupdate, msgbox, httpclient,
+                              pastebin)
 from qutebrowser.config import config
 
 
@@ -420,9 +420,6 @@ class ExceptionCrashDialog(_CrashDialog):
         text = "<b>Argh! qutebrowser crashed unexpectedly.</b>"
         self._lbl.setText(text)
 
-    def _init_buttons(self):
-        super()._init_buttons()
-
     def _init_checkboxes(self):
         """Add checkboxes to the dialog."""
         super()._init_checkboxes()
