@@ -116,7 +116,7 @@ class CrashHandler(QObject):
                                         window=win_id)
             for tab in tabbed_browser.widgets():
                 try:
-                    urlstr = tab.cur_url.toString(
+                    urlstr = tab.url().toString(
                         QUrl.RemovePassword | QUrl.FullyEncoded)
                     if urlstr:
                         win_pages.append(urlstr)
@@ -311,7 +311,7 @@ class SignalHandler(QObject):
             # pylint: disable=import-error,no-member,useless-suppression
             import fcntl
             read_fd, write_fd = os.pipe()
-            for fd in (read_fd, write_fd):
+            for fd in [read_fd, write_fd]:
                 flags = fcntl.fcntl(fd, fcntl.F_GETFL)
                 fcntl.fcntl(fd, fcntl.F_SETFL, flags | os.O_NONBLOCK)
             self._notifier = QSocketNotifier(read_fd, QSocketNotifier.Read,
