@@ -29,6 +29,7 @@ import faulthandler
 import traceback
 import warnings
 import json
+import inspect
 
 from PyQt5 import QtCore
 # Optional imports
@@ -37,6 +38,8 @@ try:
 except ImportError:
     colorama = None
 
+_log_inited = False
+
 COLORS = ['black', 'red', 'green', 'yellow', 'blue', 'purple', 'cyan', 'white']
 COLOR_ESCAPES = {color: '\033[{}m'.format(i)
                  for i, color in enumerate(COLORS, start=30)}
@@ -130,6 +133,15 @@ sessions = logging.getLogger('sessions')
 ram_handler = None
 
 
+def stub(suffix=''):
+    """Show a STUB: message for the calling function."""
+    function = inspect.stack()[1][3]
+    text = "STUB: {}".format(function)
+    if suffix:
+        text = '{} ({})'.format(text, suffix)
+    misc.warning(text)
+
+
 class CriticalQtWarning(Exception):
 
     """Exception raised when there's a critical Qt warning."""
@@ -157,9 +169,16 @@ def init_log(args):
         root.addHandler(ram)
     root.setLevel(logging.NOTSET)
     logging.captureWarnings(True)
+    _init_py_warnings()
+    QtCore.qInstallMessageHandler(qt_message_handler)
+    global _log_inited
+    _log_inited = True
+
+
+def _init_py_warnings():
+    """Initialize Python warning handling."""
     warnings.simplefilter('default')
     warnings.filterwarnings('ignore', module='pdb', category=ResourceWarning)
-    QtCore.qInstallMessageHandler(qt_message_handler)
 
 
 @contextlib.contextmanager
@@ -172,6 +191,15 @@ def disable_qt_msghandler():
         QtCore.qInstallMessageHandler(old_handler)
 
 
+@contextlib.contextmanager
+def ignore_py_warnings(**kwargs):
+    """Contextmanager to temporarily disable certain Python warnings."""
+    warnings.filterwarnings('ignore', **kwargs)
+    yield
+    if _log_inited:
+        _init_py_warnings()
+
+
 def _init_handlers(level, color, force_color, json_logging, ram_capacity):
     """Init log handlers.
 
@@ -316,6 +344,14 @@ def qt_message_handler(msg_type, context, msg):
             'QNetworkSession::State) to '
             'QNetworkReplyHttpImpl::_q_networkSessionStateChanged('
             'QNetworkSession::State)',
+        # https://bugreports.qt.io/browse/QTBUG-53989
+        "Image of format '' blocked because it is not considered safe. If you "
+            "are sure it is safe to do so, you can white-list the format by "
+            "setting the environment variable QTWEBKIT_IMAGEFORMAT_WHITELIST=",
+        # Installing Qt from the installer may cause it looking for SSL3 which
+        # may not be available on the system
+        "QSslSocket: cannot resolve SSLv3_client_method",
+        "QSslSocket: cannot resolve SSLv3_server_method",
     ]
     if sys.platform == 'darwin':
         suppressed_msgs += [
