@@ -26,7 +26,7 @@ import datetime
 import collections
 import traceback
 
-from PyQt5.QtCore import pyqtSignal, pyqtSlot, QObject
+from PyQt5.QtCore import pyqtSignal, QObject
 from PyQt5.QtWidgets import QApplication
 
 from qutebrowser.utils import usertypes, log, objreg, utils
@@ -86,7 +86,7 @@ def _wrapper(win_id, method_name, text, *args, **kwargs):
                           win in objreg.window_registry.values() and
                           win.win_id == win_id)
         if (config.get('ui', 'message-unfocused') or
-                method_name not in ('error', 'warning', 'info') or
+                method_name not in ['error', 'warning', 'info'] or
                 window_focused):
             getattr(bridge, method_name)(text, *args, **kwargs)
         else:
@@ -108,7 +108,6 @@ def _get_bridge(win_id):
     return objreg.get('message-bridge', scope='window', window=win_id)
 
 
-@pyqtSlot()
 def on_focus_changed():
     """Show queued messages when a new window has been focused.
 
@@ -311,7 +310,7 @@ class MessageBridge(QObject):
         self.s_error.emit(msg, immediately)
 
     def warning(self, msg, immediately=False, *, log_stack=True):
-        """Display an warning in the statusbar.
+        """Display a warning in the statusbar.
 
         Args:
             msg: The message to show.
