@@ -221,7 +221,8 @@ class NeighborList(collections.abc.Sequence):
 
 
 # The mode of a Question.
-PromptMode = enum('PromptMode', ['yesno', 'text', 'user_pwd', 'alert'])
+PromptMode = enum('PromptMode', ['yesno', 'text', 'user_pwd', 'alert',
+                                 'download'])
 
 
 # Where to open a clicked link.
@@ -246,6 +247,59 @@ Exit = enum('Exit', ['ok', 'reserved', 'exception', 'err_ipc', 'err_init',
                      'err_config', 'err_key_config'], is_int=True, start=0)
 
 
+# Load status of a tab
+LoadStatus = enum('LoadStatus', ['none', 'success', 'success_https', 'error',
+                                 'warn', 'loading'])
+
+
+# Backend of a tab
+Backend = enum('Backend', ['QtWebKit', 'QtWebEngine'])
+
+
+# Where a download should be saved
+class DownloadTarget:
+
+    """Abstract base class for different download targets."""
+
+    def __init__(self):
+        raise NotImplementedError
+
+
+class FileDownloadTarget(DownloadTarget):
+
+    """Save the download to the given file.
+
+    Attributes:
+        filename: Filename where the download should be saved.
+    """
+
+    def __init__(self, filename):
+        # pylint: disable=super-init-not-called
+        self.filename = filename
+
+
+class FileObjDownloadTarget(DownloadTarget):
+
+    """Save the download to the given file-like object.
+
+    Attributes:
+        fileobj: File-like object where the download should be written to.
+    """
+
+    def __init__(self, fileobj):
+        # pylint: disable=super-init-not-called
+        self.fileobj = fileobj
+
+
+class OpenFileDownloadTarget(DownloadTarget):
+
+    """Save the download in a temp dir and directly open it."""
+
+    def __init__(self):
+        # pylint: disable=super-init-not-called
+        pass
+
+
 class Question(QObject):
 
     """A question asked to the user, e.g. via the status bar.
